pub type DecodeSize = Size2D<u32, ()>;Aliased Type
pub struct DecodeSize {
pub width: u32,
pub height: u32,
}Fields
width: u32The extent of the element in the U units along the x axis (usually horizontal).
height: u32The extent of the element in the U units along the y axis (usually vertical).